@@ -3,7 +3,7 @@ package WiringPi::API;
 use strict;
 use warnings;
 
-our $VERSION = '2.36.6';
+our $VERSION = '2.36.7';
 
 require XSLoader;
 XSLoader::load('WiringPi::API', $VERSION);
@@ -19,7 +19,7 @@ my @wpi_c_functions = qw(
     wpiToGpio           physPinToGpio       pwmSetRange
     lcdInit             lcdHome             lcdClear
     lcdDisplay          lcdCursor           lcdCursorBlink
-    lcdSendCommand      lcdPosition         lcdCharDef
+    lcdSendCommand      lcdPosition         lcdDefChar
     lcdPutChar          lcdPuts             setInterrupt
     softPwmCreate       softPwmWrite        softPwmStop
     sr595Setup          bmp180Setup         bmp180Pressure
@@ -43,7 +43,7 @@ my @wpi_perl_functions = qw(
     analog_read     analog_write    pin_mode            phys_to_wpi
     ads1115_setup   spi_setup       spi_data            i2c_setup
     i2c_interface   i2c_read        i2c_read_byte       i2c_read_word
-    i2c_write       i2c_write_byte  i2c_write_word
+    i2c_write       i2c_write_byte  i2c_write_word      testChar
 );
 
 our @EXPORT_OK;
@@ -176,8 +176,22 @@ sub pwm_set_range {
 # lcd functions
 
 sub lcd_init {
-    shift if @_ == 14;
-    my @args = @_;
+    shift if @_ == 27;
+    my %params = @_;
+
+    my @required_args = qw(
+        rows cols bits rs strb
+        d0 d1 d2 d3 d4 d5 d6 d7
+    );
+
+    my @args;
+    for (@required_args){
+        if (! defined $params{$_}) {
+            die "\n'$_' is a required param for WiringPi::API::lcd_init()\n";
+        }
+        push @args, $params{$_};
+    }
+
     my $fd = lcdInit(@args); # LCD handle
     return $fd;
 }
@@ -217,7 +231,9 @@ sub lcd_position {
 sub lcd_char_def {
     shift if @_ == 4;
     my ($fd, $index, $data) = @_;
-    lcdCharDef($fd, $index, $data);
+    lcdPuts($fd, "\n");
+    my $unsigned_char = pack "C[8]", @$data;
+    lcdCharDef($fd, $index, $unsigned_char);
 }
 sub lcd_put_char {
     shift if @_ == 3;
@@ -458,16 +474,6 @@ GPIO and connected peripherals
 No matter which import option you choose, before you can start making calls,
 you must initialize the software by calling one of the C<setup*()> routines.
 
-    # import the API functions directly
-
-    use WiringPi::API qw(:wiringPi)
-
-    # import the Perl wrapped functions
-
-    use WiringPi::API qw(:perl)
-
-    # import both versions
-
     use WiringPi::API qw(:all)
 
     # use as a base class with OO functionality
@@ -486,42 +492,15 @@ This is an XS-based module, and requires L<wiringPi|http://wiringpi.com> version
 2.36+ to be installed. The C<wiringPiDev> shared library is also required (for
 the LCD functionality), but it's installed by default with C<wiringPi>.
 
-This module allows you to import the wiringPi's functions directly as-is, use
-it as a Perl base class, export the Perl wrapped functions, or use it in a
-traditional Perl OO way.
-
 See the documentation on the L<wiringPi|http://wiringpi.com> website for a more
 in-depth description of most of the functions it provides. Some of the
 functions we've wrapped are not documented, they were just selectively plucked
-from the C code itself.
+from the C code itself. Each mapped function lists which C function it is
+responsible for.
 
 =head1 EXPORT_OK
 
-Exported with the C<:wiringPi> tag.
-
-These XS functions map directly to the wiringPi functions with their original
-names. 
-
-Note that C<setInterrupt> is a custom C wrapper for C<wiringPiISR()>, as is
-C<spiDataRW> for C<wiringPiSPIDataRW()>. This is required in order to be able
-to make them usable in Perl land.
-
-    wiringPiSetup       wiringPiSetupSys    wiringPiSetupGpio
-    wiringPiSetupPhys   pinMode             pullUpDnControl
-    digitalRead         digitalWrite        digitalWriteByte
-    pwmWrite            getAlt              piBoardDev
-    wpiToGpio           physPinToGpio       pwmSetRange
-    lcdInit             lcdHome             lcdClear
-    lcdDisplay          lcdCursor           lcdCursorBlink
-    lcdSendCommand      lcdPosition         lcdCharDef
-    lcdPutChar          lcdPuts             setInterrupt
-    softPwmCreate       softPwmWrite        softPwmStop
-    sr595Setup          bmp180Setup         bmp180Pressure
-    bmp180Temp          analogRead          analogWrite
-    ads1115Setup        pseudoPinsSetup     wiringPiSPISetup
-    wiringPiSPIDataRW
-
-Exported with the C<:perl> tag.
+Exported with the C<:all> tag, or individually.
 
 Perl wrapper functions for the XS functions. Not all of these are direct
 wrappers; several have additional/modified functionality than the wrapped
@@ -540,12 +519,6 @@ versions, but are still 100% compatible.
 
 =head1 EXPORT_TAGS
 
-=head2 :wiringPi
-
-See L<EXPORT_OK>
-
-=head2 :perl
-
 See L<EXPORT_OK>
 
 =head2 :all
@@ -978,13 +951,10 @@ Mandatory: Row position. C<0> is the top row.
 
 =head2 lcd_char_def($fd, $index, $data)
 
-Maps to C<void lcdCharDef(int fd, unsigned char data [8])>
+Maps to C<void lcdCharDef(int fd, unsigned char data [8])>. This function is
 
 This allows you to re-define one of the 8 user-definable characters in the
-display. The data array is 8 bytes which represent the character from the
-top-line to the bottom line. Note that the characters are actually 5 x 8, so
-only the lower 5 bits are used. The index is from 0 to 7 and you can
-subsequently print the character defined using the lcdPutchar() call.
+display.
 
 Parameters:
 
@@ -998,7 +968,11 @@ Mandatory: Index of the display character. Values are C<0-7>.
 
     $data
 
-Mandatory: See above description.
+Mandatory: Array reference. Each element is a single byte, up to a maximum of 8
+elements. These bytes represent the character from the top-line to the bottom
+line. Note that the characters are actually 5×8, so only the lower 5 bits are
+used. The index is from 0 to 7 and you can subsequently print the character
+defined using the lcdPutchar() call.
 
 =head2 lcd_put_char($fd, $char)
 
@@ -1512,3 +1486,4 @@ Copyright (C) 2016 by Steve Bertrand
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.18.2 or,
 at your option, any later version of Perl 5 you may have available.
+
